plg_rt_init

Function plg_rt_init 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn plg_rt_init( atom_strs: *const *const c_char, atom_count: u32, registry: *const RegistryEntry, registry_len: u32, srcmap: *const SrcLoc, srcmap_len: u32, files: *const *const c_char, files_len: u32, ) -> *mut Machine
Build the Machine from the tables codegen baked into the binary. Re-interning the emitted atom names in id order reproduces the compiler’s exact id space (the interner pre-seeds the same well-known atoms the compiler’s did).

Safety

Called once from generated main with codegen-emitted tables.