#[unsafe(no_mangle)]pub unsafe extern "C" fn plg_rt_main(
m: *mut Machine,
argc: i32,
argv: *const *const c_char,
) -> i32Expand description
Run the query named in argv against the compiled program. Returns the process exit code.
Safety
Called once from generated main with the process argc/argv.